/**
 * Lance une requête GET a l'URL donnée en paramètre et retourne une Promise.
 * @param url {String} - URL de la requête
 * @returns {Promise<Response>}
 */
export function get(url) {
    return (
        fetch(url, {
            method: 'GET',
            verify: false,
            credentials: 'include',
        })
    )
}

/**
 * Lance une requête GET a l'URL donnée en paramètre et retourne une Promise.
 * Dans ce cas particulier, on ajoute un header d'authentification.
 * @param url {String} - URL de la requête
 * @param login {String} - Identifiant
 * @param pass {String} - Mot de passe
 * @returns {Promise<Response>}
 */
export function getLogin(url, login, pass) {
    return (
        fetch(url, {
            method: 'GET',
            verify: false,
            credentials: 'include',
            headers: {
                'Content-Type': 'application/x-www-form-urlencoded',
                'Authorization': 'Basic ' + btoa(login + ":" + pass)
            },
        })
    )
}

/**
 * Lance une requête GET a l'URL donnée en paramètre et retourne les données JSON d'une Promise.
 * @param url {String} - URL de la requête
 * @returns {Promise<{data: any}>}
 */
export function getJson(url) {
    return get(url)
        .then(response => response.json()
            .then(data => ({data: data}))
                .then(res => {return res})
        );
}

/**
 * Lance une requête POST a l'URL donnée en paramètre et retourne une Promise.
 * @param url {String} - URL de la requête
 * @param data {String} - Données de la requête au format "param1=val1&param2=val2..."
 * @returns {Promise<Response>}
 */
export function post(url, data) {
    return (
        fetch(url, {
            method: 'POST',
            verify: false,
            credentials: 'include',
            headers: {'Content-Type': 'application/x-www-form-urlencoded'},
            body: data
        })
    )
}